==> aim-transport-0.8.0.tar.gz: aim-transport-0.8.0/src/messages.c <==
#include "aimtrans.h"

int at_parse_incoming_im(struct aim_session_t *ass, 
                         struct command_rx_struct *command, ...)
{
	int channel;
	va_list ap;

	va_start(ap, command);
	channel = va_arg(ap, int);

	/*
	* Channel 1: Standard Message
	*/
	if (channel == 1)
	{
    	struct aim_userinfo_s *userinfo;
	    char *msg = NULL;
    	u_int icbmflags = 0;
    	u_short flag1, flag2;
		jpacket jp;
		xmlnode par;
		xmlnode node;
		session s;
		jid from;
  
	    userinfo = va_arg(ap, struct aim_userinfo_s *);
    	msg = va_arg(ap, char *);
	    icbmflags = va_arg(ap, u_int);
    	flag1 = va_arg(ap, u_short);
	    flag2 = va_arg(ap, u_short);
    	va_end(ap);

		s = (session)ass->aux_data;


        /* XXX: This is butt ugly until the rewrite */
		par = xmlnode_new_tag("message");
		xmlnode_put_attrib(par, "type", "chat");
		xmlnode_put_attrib(par, "to", jid_full(s->cur));
		xmlnode_put_attrib(par, "from", at_name);
		jp = jpacket_new(par);
		node = xmlnode_insert_tag(jp->x, "body");
        msg = (char *)strip_html(msg, jp->p);
		msg = (char *)str_to_UTF8(jp->p, (unsigned char *)msg);
		xmlnode_insert_cdata(node, j_strdup(msg), strlen(msg));


		jid_set(jp->from, at_normalize((char *)userinfo->sn), JID_USER);
                xmlnode_put_attrib(jp->x,"from",jid_full(jp->from));

		log_debug(ZONE, "[AIM] Sending: %s\n", xmlnode2str(jp->x));
		ehandler_send(ehandler_at, jp->x, s->cur->server);
		
        /* XXX I'm dumb, left for stupid reflection
         * the pool frees this
         *
         * free(msg);
         *
         */

	}
	else if(channel == 2)
	{
		/* XXX decide how to handle groupchat requests */
		/* XXX Actualy parse and use this */
	}

  return 1;
}

int at_parse_misses(struct aim_session_t *sess, 
                    struct command_rx_struct *command, ...)
{
    xmlnode x;
    xmlnode body;
    jpacket jp;
    session s;

    static char *missedreasons[] = {
        "Unknown",
        "Message too large"};
    static int missedreasonslen = 2;

    va_list ap;
    unsigned short chan, nummissed, reason;
    struct aim_userinfo_s *userinfo;
    char msg[1024];

    s = (session)sess->aux_data;

	x = xmlnode_new_tag("message");
	xmlnode_put_attrib(x, "to", jid_full(s->cur));
	xmlnode_put_attrib(x, "from", at_name);
	xmlnode_put_attrib(x, "type","error");
	body = xmlnode_insert_tag(x, "error");
  
    va_start(ap, command);
    chan = va_arg(ap, unsigned short);
    userinfo = va_arg(ap, struct aim_userinfo_s *);
    nummissed = va_arg(ap, unsigned short);
    reason = va_arg(ap, unsigned short);
    va_end(ap);

    memset(&msg, '\0', 1024);
    snprintf((char *)&msg, 1024, "Missed %d messages from %s (reason %d: %s)", 
             nummissed, userinfo->sn, reason, 
             (reason<missedreasonslen)?missedreasons[reason]:"unknown");
  
    xmlnode_insert_cdata(body, (char *)&msg, strlen((char *)&msg));

    jp = jpacket_new(x);
	ehandler_send(ehandler_at, jp->x, s->cur->server);
    return 1;
}

int at_parse_msgerr(struct aim_session_t *sess, struct command_rx_struct *command, ...)
{
    xmlnode x;
    xmlnode body;
    jpacket jp;
    session s;
    char msg[1024];

    va_list ap;
    char *destsn;
    unsigned short reason;

    va_start(ap, command);
    destsn = va_arg(ap, char *);
    reason = va_arg(ap, unsigned short);
    va_end(ap);

    memset((char *)&msg, '\0', 1024);
    snprintf((char *)&msg, 1024, 
             "faimtest: message to %s bounced (reason 0x%04x: %s)\n", 
             destsn, reason, 
             (reason<msgerrreasonslen)?msgerrreasons[reason]:"unknown");

    s = (session)sess->aux_data;

	x = xmlnode_new_tag("message");
	xmlnode_put_attrib(x, "to", jid_full(s->cur));
	xmlnode_put_attrib(x, "from", at_name);
	xmlnode_put_attrib(x, "type","error");
	body = xmlnode_insert_tag(x, "error");
    xmlnode_insert_cdata(body, (char *)&msg, strlen((char *)&msg));
  
    return 1;
}

==> aim-transport-0.8.5.tar.gz: aim-transport-0.8.5/src/messages.c <==
#include "aimtrans.h"

int at_parse_incoming_im(struct aim_session_t *ass, 
                         struct command_rx_struct *command, ...)
{
	int channel;
	va_list ap;

	va_start(ap, command);
	channel = va_arg(ap, int);

	/*
	* Channel 1: Standard Message
	*/
	if (channel == 1)
	{
    	struct aim_userinfo_s *userinfo;
	    char *msg = NULL;
    	u_int icbmflags = 0;
    	u_short flag1, flag2;
		jpacket jp;
		xmlnode par;
		xmlnode node;
		session s;
		jid from;
  
	    userinfo = va_arg(ap, struct aim_userinfo_s *);
    	msg = va_arg(ap, char *);
	    icbmflags = va_arg(ap, u_int);
	    flag1 = va_arg(ap, u_int);
	    flag2 = va_arg(ap, u_int);
    	va_end(ap);

		s = (session)ass->aux_data;


        /* XXX: This is butt ugly until the rewrite */
		par = xmlnode_new_tag("message");
		xmlnode_put_attrib(par, "type", "chat");
		xmlnode_put_attrib(par, "to", jid_full(s->cur));
		xmlnode_put_attrib(par, "from", at_name);
		jp = jpacket_new(par);
		node = xmlnode_insert_tag(jp->x, "body");
        msg = (char *)strip_html(msg, jp->p);
		msg = (char *)str_to_UTF8(jp->p, (unsigned char *)msg);
		xmlnode_insert_cdata(node, j_strdup(msg), strlen(msg));


		jid_set(jp->from, at_normalize((char *)userinfo->sn), JID_USER);
                xmlnode_put_attrib(jp->x,"from",jid_full(jp->from));

		log_debug(ZONE, "[AIM] Sending: %s\n", xmlnode2str(jp->x));
		ehandler_send(ehandler_at, jp->x, s->cur->server);
		
        /* XXX I'm dumb, left for stupid reflection
         * the pool frees this
         *
         * free(msg);
         *
         */

	}
	else if(channel == 2)
	{
		/* XXX decide how to handle groupchat requests */
		/* XXX Actualy parse and use this */
	}

  return 1;
}

int at_parse_misses(struct aim_session_t *sess, 
                    struct command_rx_struct *command, ...)
{
    xmlnode x;
    xmlnode body;
    jpacket jp;
    session s;

    static char *missedreasons[] = {
        "Unknown",
        "Message too large"};
    static int missedreasonslen = 2;

    va_list ap;
    unsigned short chan, nummissed, reason;
    struct aim_userinfo_s *userinfo;
    char msg[1024];

    s = (session)sess->aux_data;

	x = xmlnode_new_tag("message");
	xmlnode_put_attrib(x, "to", jid_full(s->cur));
	xmlnode_put_attrib(x, "from", at_name);
	xmlnode_put_attrib(x, "type","error");
	body = xmlnode_insert_tag(x, "error");
  
    va_start(ap, command);
    chan = va_arg(ap, u_int);
    userinfo = va_arg(ap, struct aim_userinfo_s *);
    nummissed = va_arg(ap, u_int);
    reason = va_arg(ap, u_int);
    va_end(ap);

    memset(&msg, '\0', 1024);
    snprintf((char *)&msg, 1024, "Missed %d messages from %s (reason %d: %s)", 
             nummissed, userinfo->sn, reason, 
             (reason<missedreasonslen)?missedreasons[reason]:"unknown");
  
    xmlnode_insert_cdata(body, (char *)&msg, strlen((char *)&msg));

    jp = jpacket_new(x);
	ehandler_send(ehandler_at, jp->x, s->cur->server);
    return 1;
}

int at_parse_msgerr(struct aim_session_t *sess, struct command_rx_struct *command, ...)
{
    xmlnode x;
    xmlnode body;
    jpacket jp;
    session s;
    char msg[1024];

    va_list ap;
    char *destsn;
    unsigned short reason;

    va_start(ap, command);
    destsn = va_arg(ap, char *);
    reason = va_arg(ap, u_int);
    va_end(ap);

    memset((char *)&msg, '\0', 1024);
    snprintf((char *)&msg, 1024, 
             "faimtest: message to %s bounced (reason 0x%04x: %s)\n", 
             destsn, reason, 
             (reason<msgerrreasonslen)?msgerrreasons[reason]:"unknown");

    s = (session)sess->aux_data;

	x = xmlnode_new_tag("message");
	xmlnode_put_attrib(x, "to", jid_full(s->cur));
	xmlnode_put_attrib(x, "from", at_name);
	xmlnode_put_attrib(x, "type","error");
	body = xmlnode_insert_tag(x, "error");
    xmlnode_insert_cdata(body, (char *)&msg, strlen((char *)&msg));
  
    return 1;
}
